#!/bin/bash
#
# cortana_enable.sh
# Modified: 2025/03/11 12:00:00
# Derechos de Autor (C) [2025] [Mauro Rosero P. <mauro@rosero.one> (mauro.rosero@gmail.com)]
#
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Script para activar el alias 'cortana' para Claude Code
# Uso:
#   ./cortana_enable.sh

DEVSPATH=devs
BIN_HOME=$HOME/$DEVSPATH
BIN_MESG=bin/msg
BIN_LIBS=bin/lib
BIN_CFGS=bin/config
VERSION=1.0.0

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# LOAD BASE BASH LIBRARY
source $BIN_HOME/$BIN_LIBS/base.lib

# Load head messages
load_messages $BIN_HOME $BIN_MESG $BIN_LANG "head"
title="${head_000} ${head_002}"

# Verificar que 'dialog' esté instalado
if ! command -v dialog &>/dev/null; then
  echo "${npm_001}"
  exit 1
fi

# Confirmar activación
dialog --backtitle "${title}" --title "${npm_031}" --yesno "¿Desea activar el alias 'cortana' para Claude Code?" 7 50
if [[ $? -eq 0 ]]; then
  # Crear un archivo fuente para la activación del alias
  ALIAS_FILE="$BIN_HOME/bin/cortana_alias.sh"
  echo '#!/bin/bash' > "$ALIAS_FILE"
  echo '# Verificar si ~/.npm-global/bin está en el PATH' >> "$ALIAS_FILE"
  echo 'if [[ ":$PATH:" != *":$HOME/.npm-global/bin:"* ]]; then' >> "$ALIAS_FILE"
  echo '  # Si no está en el PATH, usamos la ruta completa en el alias' >> "$ALIAS_FILE"
  echo '  alias cortana="$HOME/.npm-global/bin/claude"' >> "$ALIAS_FILE"
  echo 'else' >> "$ALIAS_FILE"
  echo '  # Si está en el PATH, podemos usar el nombre directamente' >> "$ALIAS_FILE"
  echo '  alias cortana="claude"' >> "$ALIAS_FILE"
  echo 'fi' >> "$ALIAS_FILE"
  echo 'echo "Alias cortana activado en la sesión actual."' >> "$ALIAS_FILE"
  chmod +x "$ALIAS_FILE"
  
  # Ejecutar la función cortana_alias del biblioteca base.lib para el archivo de configuración permanente
  cortana_alias
  
  # Crear un mensaje con instrucciones para activar el alias en la sesión actual
  dialog --backtitle "${title}" --title "${npm_036}" --msgbox "${npm_037}\n\nPara activar el alias en la sesión actual, ejecute:\n\nsource $ALIAS_FILE\n\n" 10 70
else
  dialog --backtitle "${title}" --title "${head_canceled}" --msgbox "${npm_008}" 6 40
  exit 1
fi